trailing property
A widget displayed at the end of the EnhancedCupertinoListTile. This is usually
a right chevron icon (e.g. CupertinoListTileChevron), or an Icon.
Implementation
final Widget? trailing;
A widget displayed at the end of the EnhancedCupertinoListTile. This is usually
a right chevron icon (e.g. CupertinoListTileChevron), or an Icon.
final Widget? trailing;