checkMarkLocation property
Determines whether the check mark will be located on the leading (left) or trailing (right) side of the tile.
Implementation
final WidgetSelectionLocation checkMarkLocation;
Determines whether the check mark will be located on the leading (left) or trailing (right) side of the tile.
final WidgetSelectionLocation checkMarkLocation;