CupertinoSelection<T> class

Provides a list of options. Most users will use CupertinoMultiSelection or CupertinoSingleSelection, but CupertinoSelection can be used to create custom behaviour.

Inheritance

Constructors

CupertinoSelection({required List<Widget> children, required Widget? header, required Widget? footer, CupertinoListSectionType? headerType, CupertinoListSectionType? footerType, Color? backgroundColor, Color? separatorColor, Key? key})
const

Properties

backgroundColor Color?
Optional background color
final
children List<Widget>
The options from which the user can choose.
final
Displayed below the options. Usually a Text widget.
final
footerType CupertinoListSectionType
The type of the footer. If "insetGrouped", no styling will be applied. If "base", the footer will be displayed in the style of the iOS settings app.
final
hashCode int
The hash code for this object.
no setterinherited
Displayed above the options. Usually a Text widget.
final
headerType CupertinoListSectionType
The type of the header. If "insetGrouped", the header will be displayed large and bold like the iOS notes app. If "base", the header will be displayed smaller, like the iOS settings app.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
separatorColor Color?
Optional separator color
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited