subtitle property
subtitle will passed to the subtitle argument of CupertinoSingleSelection and CupertinoMultiSelection.
Implementation
final Widget? subtitle;
subtitle will passed to the subtitle argument of CupertinoSingleSelection and CupertinoMultiSelection.
final Widget? subtitle;