title property
title will passed to the title argument of CupertinoSingleSelection and CupertinoMultiSelection.
Implementation
final Widget title;
title will passed to the title argument of CupertinoSingleSelection and CupertinoMultiSelection.
final Widget title;