SelectionItem<T> class
Constructors
- SelectionItem({required Widget title, Widget? subtitle, T? value, bool enabled = true})
Properties
- enabled → bool
-
Determines if this option can be selected or deselected by the user.
If false, the tile will be greyed out and not selectable by the user.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitle → Widget?
-
subtitlewill passed to thesubtitleargument of CupertinoSingleSelection and CupertinoMultiSelection.final - title → Widget
-
titlewill passed to thetitleargument of CupertinoSingleSelection and CupertinoMultiSelection.final - value → T?
-
The value that will be provided through the on onChanged callbacks of
CupertinoSingleSelection and CupertinoMultiSelection upon clicking the tile.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited